version 14.1

clear all
capture log close
set more off

/* Insert your own pathname here */
cd "/Users/nnunn/Dropbox (Nathan Nunn)/Kuba Kingdom/Lowes_et_al_ECMA_Replication_Files/"

ssc install outreg2

log using "Lowes_et_al_ECMA_Replication.log", replace

use "Lowes_et_al_ECMA_Replication.dta", clear

local baseline_controls "age age2 female i.year"

*************************************
*** TABLE 1: Baseline Regressions ***
*************************************

****************************
*** Panel A. No controls ***
****************************

*** RAG ***
/* Full sample */
reg avg_gives kuba_ethnicity
outreg2 using "tables/T1_panelA_Baseline_no_controls.xls", replace 
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg avg_gives kuba_central
outreg2 using "tables/T1_panelA_Baseline_no_controls.xls", append 
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg avg_gives kuba_bushong
outreg2 using "tables/T1_panelA_Baseline_no_controls.xls", append 
sum avg_gives if e(sample)==1
restore

*** Missing Money ***
/* Full sample */
reg net_missing_dgug kuba_ethnicity
outreg2 using "tables/T1_panelA_Baseline_no_controls.xls", append 
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg net_missing_dgug kuba_central
outreg2 using "tables/T1_panelA_Baseline_no_controls.xls", append
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg net_missing_dgug kuba_bushong
outreg2 using "tables/T1_panelA_Baseline_no_controls.xls", append 
sum net_missing_dgug if e(sample)==1
restore

*******************************
*** Panel B. Basic Controls ***
*******************************
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/T1_panelB_Baseline_controls.xls", replace 
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls'
outreg2 using "tables/T1_panelB_Baseline_controls.xls", append 
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls'
outreg2 using "tables/T1_panelB_Baseline_controls.xls", append 
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls'
outreg2 using "tables/T1_panelB_Baseline_controls.xls", append 
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls'
outreg2 using "tables/T1_panelB_Baseline_controls.xls", append 
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls'
outreg2 using "tables/T1_panelB_Baseline_controls.xls", append 
sum net_missing_dgug if e(sample)==1
restore

********************************************
*** Table 2 Panel A: Baseline variables ***
********************************************

gen year2_dum=0 if missing(year)!=1
replace year2_dum=1 if year==2014

/* Full Sample */
preserve
reg age 
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", replace
reg age kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append

reg female
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg female kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append

reg year2_dum 
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg year2_dum kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg age 
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg age kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append

reg female
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg female kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append

reg year2_dum 
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg year2_dum kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg age 
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg age kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append

reg female
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg female kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append

reg year2_dum 
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
reg year2_dum kuba_ethnicity
outreg2 using "tables/T2_panelA_Balance_baseline_chars.xls", append
restore


*********************************************************
*** TABLE 2, Panel B: Balance Immigration Information ***
*********************************************************

** Full Sample **
preserve
/* Are you an immigrant to Kananga? */
reg immigrant_Kananga 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", replace
reg immigrant_Kananga kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg immigrant_Kananga kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
			
/* Fraction of life in Kananga */
reg frac_life_Kananga
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg frac_life_Kananga kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg frac_life_Kananga kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append

/* Are your 5 closes friends the same ethnicity? */
reg group_same_ethnicity 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg group_same_ethnicity kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg group_same_ethnicity kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append	

/* Polygon living in: Percentage of population of the same ethnicity */
reg percent_same 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg percent_same kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg percent_same kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append	

/* Polygon living in: HI of ethnic concentration */
reg hhi_final
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg hhi_final kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg hhi_final kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
restore

*** Central Kuba Sample ***

preserve
keep if kuba_central==1 | lele_ethnicity==1

/* Are you an immigrant to Kananga? */
reg immigrant_Kananga 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg immigrant_Kananga kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg immigrant_Kananga kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
			
/* Fraction of life in Kananga */
reg frac_life_Kananga
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg frac_life_Kananga kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg frac_life_Kananga kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append

/* Are your 5 closes friends the same ethnicity? */
reg group_same_ethnicity 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg group_same_ethnicity kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg group_same_ethnicity kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append	

/* Polygon living in: Percentage of population of the same ethnicity */
reg percent_same 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg percent_same kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg percent_same kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append	

/* Polygon living in: HI of ethnic concentration */
reg hhi_final
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg hhi_final kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg hhi_final kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
restore

*** Bushong Sample ***

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
/* Are you an immigrant to Kananga? */
reg immigrant_Kananga 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg immigrant_Kananga kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg immigrant_Kananga kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
			
/* Fraction of life in Kananga */
reg frac_life_Kananga
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg frac_life_Kananga kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg frac_life_Kananga kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append

/* Are your 5 closes friends the same ethnicity? */
reg group_same_ethnicity 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg group_same_ethnicity kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg group_same_ethnicity kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append	

/* Polygon living in: Percentage of population of the same ethnicity */
reg percent_same 
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg percent_same kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg percent_same kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append	

/* Polygon living in: HI of ethnic concentration */
reg hhi_final
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg hhi_final kuba_ethnicity
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
reg hhi_final kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelB_Balance_immigration.xls", append
restore

*******************************************
*** Table 2, Panel C: Geography Balance ***
*******************************************

/* Full Sample */
preserve
reg suitability_maize, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", replace
reg suitability_maize kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_maize kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append

reg suitability_cassava, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_cassava kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_cassava kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg suitability_maize, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_maize kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_maize kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append

reg suitability_cassava, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_cassava kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_cassava kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg suitability_maize, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_maize kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_maize kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append

reg suitability_cassava, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_cassava kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
reg suitability_cassava kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T2_panelC_Balance_geography.xls", append
restore

*******************************************
*** Table 2, Panel D: Trust Researchers ***
*******************************************

/* Full Sample */
preserve
reg trust_int_org 
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", replace
reg trust_int_org kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_int_org kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append

reg trust_other_nat
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_other_nat kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_other_nat kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append

reg trust_univ 
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_univ kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_univ kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg trust_int_org 
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_int_org kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_int_org kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append

reg trust_other_nat
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_other_nat kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_other_nat kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append

reg trust_univ 
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_univ kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_univ kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg trust_int_org
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_int_org kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_int_org kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append

reg trust_other_nat
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_other_nat kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_other_nat kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append

reg trust_univ 
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_univ kuba_ethnicity
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
reg trust_univ kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelD_Balance_Trust_Us.xls", append
restore

**********************************
*** Table 2, Panel E: Altruism ***
**********************************

/* Full Sample */
preserve
reg DG_citizen 
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", replace
reg DG_citizen kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_citizen kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_own_tribe
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_own_tribe kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_own_tribe kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_other_tribe
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_other_tribe kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_other_tribe kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_govt 
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_govt kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_govt kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_avg_gives
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_avg_gives kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg DG_citizen
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_citizen kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_citizen kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_own_tribe
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_own_tribe kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_own_tribe kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_other_tribe
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_other_tribe kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_other_tribe kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_govt 
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_govt kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_govt kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_avg_gives
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_avg_gives kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg DG_citizen
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_citizen kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_citizen kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_own_tribe
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_own_tribe kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_own_tribe kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_other_tribe
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_other_tribe kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_other_tribe kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_govt 
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_govt kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_govt kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append

reg DG_avg_gives
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_avg_gives kuba_ethnicity
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
reg DG_avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelE_Balance_Altruism.xls", append
restore

**************************************************************
*** Table 2, Panel F: Differences in Understanding of Game ***
**************************************************************

/* Full Sample */
preserve
reg avg_wrong 
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", replace
reg avg_wrong kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg avg_wrong kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append

reg def_tq_avg
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg def_tq_avg kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg def_tq_avg kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append

reg rag_tq_avg
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg rag_tq_avg kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg rag_tq_avg kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg avg_wrong
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg avg_wrong kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg avg_wrong kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append

reg def_tq_avg
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg def_tq_avg kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg def_tq_avg kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append

reg rag_tq_avg
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg rag_tq_avg kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg rag_tq_avg kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg avg_wrong
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg avg_wrong kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg avg_wrong kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append

reg def_tq_avg
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg def_tq_avg kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg def_tq_avg kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append

reg rag_tq_avg
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg rag_tq_avg kuba_ethnicity
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
reg rag_tq_avg kuba_ethnicity `baseline_controls'
outreg2 using "tables/T2_panelF_Balance_Understanding_of_Game.xls", append
restore

**********************************
*** Table 3: Testing Tabellini ***
**********************************

/* All Traits */
xi: reg all_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", replace dec(3)
sum all_traits 

preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg all_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum all_traits 
restore

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg all_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum all_traits 
restore

/* Relevant Traits */
xi: reg relevant_traits kuba_ethnicity `baseline_controls'
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum relevant_traits 

preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg relevant_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum relevant_traits 
restore

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg relevant_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum relevant_traits 
restore

/* Irrelevant Traits */
xi: reg irrelevant_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum irrelevant_traits 

preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg irrelevant_traits kuba_ethnicity `baseline_controls'
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum irrelevant_traits
restore

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg irrelevant_traits kuba_ethnicity `baseline_controls' 
outreg2 using "tables/T3_Vertical_transmission.xls", append dec(3)
sum irrelevant_traits 
restore


***********************************************
*** Table 4, Panel A: Differences in Income ***
***********************************************

pca C35_1 ln_annual_income ln_hh_monthly_income unemployed education good_floor good_roof meals_per_day bed_hungry_pastweek height weight_height
predict pc1

pca C35_1 ln_annual_income ln_hh_monthly_income unemployed education good_floor good_roof meals_per_day bed_hungry_pastweek /*height weight_height*/
predict pc2

/* Full sample */
preserve
reg C35_1 
outreg2 using "tables/T4_panelA_Balance_Income.xls", replace dec(3)
reg C35_1 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg C35_1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg ln_annual_income 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_annual_income kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_annual_income kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg ln_hh_monthly_income 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_hh_monthly_income kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_hh_monthly_income kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg unemployed 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg unemployed kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg unemployed kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg meals_per_day 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg meals_per_day kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg meals_per_day kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg bed_hungry_pastweek 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg bed_hungry_pastweek kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg bed_hungry_pastweek kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg good_floor 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_floor kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_floor kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg good_roof 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_roof kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_roof kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg education 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg education kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg education kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg height 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg height kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg height kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg weight_height 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg weight_height kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg weight_height kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg pc1 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc1 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg pc2 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc2 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc2 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg C35_1
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg C35_1 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg C35_1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg ln_annual_income 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_annual_income kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_annual_income kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg ln_hh_monthly_income 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_hh_monthly_income kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_hh_monthly_income kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg unemployed 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg unemployed kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg unemployed kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg meals_per_day 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg meals_per_day kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg meals_per_day kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg bed_hungry_pastweek 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg bed_hungry_pastweek kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg bed_hungry_pastweek kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg good_floor 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_floor kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_floor kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg good_roof 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_roof kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_roof kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg education 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg education kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg education kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg height 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg height kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg height kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg weight_height 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg weight_height kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg weight_height kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg pc1 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc1 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg pc2 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc2 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc2 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
restore

/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg C35_1
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg C35_1 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg C35_1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg ln_annual_income 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_annual_income kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_annual_income kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg ln_hh_monthly_income 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_hh_monthly_income kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg ln_hh_monthly_income kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg unemployed 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg unemployed kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg unemployed kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg meals_per_day 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg meals_per_day kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg meals_per_day kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg bed_hungry_pastweek 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg bed_hungry_pastweek kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg bed_hungry_pastweek kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg good_floor 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_floor kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_floor kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg good_roof 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_roof kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg good_roof kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg education 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg education kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg education kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg height 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg height kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg height kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg weight_height 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg weight_height kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg weight_height kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg pc1 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc1 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)

reg pc2 
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc2 kuba_ethnicity
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
reg pc2 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelA_Balance_Income.xls", append dec(3)
restore
drop pc1 pc2

*************************************************************
*** Table 4, Panel B: Differences in Colonial Investments ***
*************************************************************

/* Full Sample */
preserve
reg I_any_mission, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", replace
reg I_any_mission kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_any_mission kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_electricity_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_electricity_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_electricity_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_railroad_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_railroad_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_railroad_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_mines_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_mines_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_mines_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg I_any_mission, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_any_mission kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_any_mission kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_electricity_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_electricity_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_electricity_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_railroad_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_railroad_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_railroad_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_mines_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_mines_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_mines_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg I_any_mission, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_any_mission kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_any_mission kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_electricity_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_electricity_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_electricity_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_railroad_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_railroad_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_railroad_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append

reg I_dist_mines_1951, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_mines_1951 kuba_ethnicity, cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
reg I_dist_mines_1951 kuba_ethnicity `baseline_controls', cluster(village_group)
outreg2 using "tables/T4_panelB_Balance_Colonial.xls", append
restore


***********************************************
*** Table 4, Panel C: Differences in Mobutu ***
***********************************************

/* Full Sample */
preserve
reg iat_leaders_q1
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", replace
reg iat_leaders_q1 kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append

reg iat_leaders_q2
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q2 kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q2 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append

reg IAT_Mobutu
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg IAT_Mobutu kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg IAT_Mobutu kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
restore

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg iat_leaders_q1
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q1 kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append

reg iat_leaders_q2
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q2 kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q2 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append

reg IAT_Mobutu
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg IAT_Mobutu kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg IAT_Mobutu kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
restore

/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg iat_leaders_q1
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q1 kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q1 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append

reg iat_leaders_q2
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q2 kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg iat_leaders_q2 kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append

reg IAT_Mobutu
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg IAT_Mobutu kuba_ethnicity
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
reg IAT_Mobutu kuba_ethnicity `baseline_controls'
outreg2 using "tables/T4_panelC_Balance_Post_Colonial.xls", append
restore


***********************************
***********************************
****                           **** 
**** APPENDIX TABLES & FIGURES ****
****                           ****
***********************************
***********************************

*********************************************
*** Appendix Figure A1: Histogram figures ***
*********************************************

*** Full Sample ***
twoway histogram avg_gives if !kuba_ethnicity,                              				///
start(0) width(100) bfcolor(none) blcolor(emidblue) lwidth(medthick)   			///
|| histogram avg_gives if kuba_ethnicity, xtitle("Amount given in RAG: average over 4 rounds") start(0) width(100) barw(70) ///
bfcolor(none) blcolor(sand) lwidth(medthick)                                  				///
legend(order(1 "Non-Kuba" 2 "Kuba") pos(2) ring(0) col(1))
graph export "graphs/A1a_Histo_RAG_average.pdf", replace

*** Central Kuba & Lele ***
preserve
keep if lele==1 | kuba_central==1
twoway histogram avg_gives if !kuba_central,                              					///
start(0) width(100) bfcolor(none) blcolor(emidblue) lwidth(medthick)   			///
|| histogram avg_gives if kuba_central, xtitle("Amount given in RAG: average over 4 rounds") start(0) width(100) barw(70) ///
bfcolor(none) blcolor(sand) lwidth(medthick)                                  				///
legend(order(1 "Lele" 2 "Central Kuba") pos(11) ring(0) col(1))
graph export "graphs/A1b_Histo_RAG_average_CKL.pdf", replace
restore

*** Bushong & Lele ***
preserve
keep if lele==1 | kuba_bushong==1
twoway histogram avg_gives if !kuba_bushong,                              					///
start(0) width(100) bfcolor(none) blcolor(emidblue) lwidth(medthick)   			///
|| histogram avg_gives if kuba_bushong, xtitle("Amount given in RAG: average over 4 rounds") start(0) width(100) barw(70) ///
bfcolor(none) blcolor(sand) lwidth(medthick)                                  				///
legend(order(1 "Lele" 2 "Bushong") pos(11) ring(0) col(1))
graph export "graphs/A1c_Histo_RAG_average_BL.pdf", replace
restore

*****************************************************
*** Appendix TABLE A1: Baseline estimates by game ***
*****************************************************

* Citizen of Kananga
xi: reg k_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", replace dec(2)
sum k_pl1_gives if e(sample)==1
* Own tribe
xi: reg g_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum g_pl1_gives if e(sample)==1
* Other tribe
xi: reg h_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum h_pl1_gives if e(sample)==1
* Govt
xi: reg i_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum i_pl1_gives if e(sample)==1
* Average
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum avg_gives if e(sample)==1

preserve
keep if kuba_central==1 | lele_ethnicity==1
* Citizen of Kananga
xi: reg k_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum k_pl1_gives if e(sample)==1
* Own tribe
xi: reg g_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum g_pl1_gives if e(sample)==1
* Other tribe
xi: reg h_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum h_pl1_gives if e(sample)==1
* Govt
xi: reg i_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum i_pl1_gives if e(sample)==1
* Average
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
* Citizen of Kananga
xi: reg k_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum k_pl1_gives if e(sample)==1
* Own tribe
xi: reg g_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum g_pl1_gives if e(sample)==1
* Other tribe
xi: reg h_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum h_pl1_gives if e(sample)==1
* Govt
xi: reg i_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum i_pl1_gives if e(sample)==1
* Average
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A1_Baseline_disagg.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

***********************************************
*** Appendix table A2: Quantile Regressions ***
***********************************************

set seed 999
*** RAG ***
/* Full sample */
xi: sqreg avg_gives kuba_ethnicity `baseline_controls', quantile(.2 .3 .4 .5 .6 .7 .8) reps(200)
outreg2 using "tables/A2_Quantile.xls", replace dec(2)
test [q20=q30=q40=q50=q60=q70=q80]: kuba_ethnicity

/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: sqreg avg_gives kuba_central `baseline_controls', quantile(.2 .3 .4 .5 .6 .7 .8) reps(200)
outreg2 using "tables/A2_Quantile.xls", append dec(2)
test [q20=q30=q40=q50=q60=q70=q80]: kuba_central
restore

/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: sqreg avg_gives kuba_bushong `baseline_controls', quantile(.2 .3 .4 .5 .6 .7 .8) reps(200)
outreg2 using "tables/A2_Quantile.xls", append dec(2)
test [q20=q30=q40=q50=q60=q70=q80]: kuba_bushong
restore

*******************************************************************
*** Appendix Table A3: Heterogeneity: By subtribe (full sample) ***
*******************************************************************

gen kuba_central_non_bushong=kuba_central-kuba_bushong

*** RAG ***
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A3_Heterogeneity_status.xls", replace 
sum avg_gives if e(sample)==1

xi: reg avg_gives kuba_central kuba_non_central `baseline_controls'
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum avg_gives if e(sample)==1
test kuba_central=kuba_non_central

xi: reg avg_gives kuba_bushong kuba_non_bushong `baseline_controls'
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum avg_gives if e(sample)==1
test kuba_bushong=kuba_non_bushong

xi: reg avg_gives kuba_central_non_bushong kuba_bushong kuba_non_central `baseline_controls' 
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum avg_gives if e(sample)==1
test kuba_central_non_bushong=kuba_bushong=kuba_non_central

*** Missing Money ***
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls'
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum net_missing_dgug if e(sample)==1

xi: reg net_missing_dgug kuba_central kuba_non_central `baseline_controls' 
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum net_missing_dgug if e(sample)==1
test kuba_central=kuba_non_central

xi: reg net_missing_dgug kuba_bushong kuba_non_bushong `baseline_controls'
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum net_missing_dgug if e(sample)==1
test kuba_bushong=kuba_non_bushong

xi: reg net_missing_dgug kuba_central_non_bushong kuba_bushong kuba_non_central `baseline_controls'
outreg2 using "tables/A3_Heterogeneity_status.xls", append 
sum avg_gives if e(sample)==1
test kuba_central_non_bushong=kuba_bushong=kuba_non_central


************************************************************************
*** Appendix Table A4: Heterogeneity: By subtribe (Kuba & Lele only) ***
************************************************************************

preserve
keep if kuba_ethnicity==1 | lele_ethnicity==1
*** RAG ***
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A4_Heterogeneity_status2.xls", replace dec(2)
sum avg_gives if e(sample)==1

xi: reg avg_gives kuba_central kuba_non_central `baseline_controls'
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum avg_gives if e(sample)==1
test kuba_central=kuba_non_central

xi: reg avg_gives kuba_bushong kuba_non_bushong `baseline_controls'
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum avg_gives if e(sample)==1
test kuba_bushong=kuba_non_bushong

xi: reg avg_gives kuba_central_non_bushong kuba_bushong kuba_non_central `baseline_controls'
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum avg_gives if e(sample)==1
test kuba_central_non_bushong=kuba_bushong=kuba_non_central

*** Missing Money ***
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' 
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum net_missing_dgug if e(sample)==1

xi: reg net_missing_dgug kuba_central kuba_non_central `baseline_controls' 
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
test kuba_central=kuba_non_central

xi: reg net_missing_dgug kuba_bushong kuba_non_bushong `baseline_controls' 
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
test kuba_bushong=kuba_non_bushong

xi: reg net_missing_dgug kuba_central_non_bushong kuba_bushong kuba_non_central `baseline_controls' 
outreg2 using "tables/A4_Heterogeneity_status2.xls", append dec(2)
sum avg_gives if e(sample)==1
test kuba_central_non_bushong=kuba_bushong=kuba_non_central
restore

*******************************************************
*** Appendix TABLE A5: Rasons for moving to Kananga ***
*******************************************************
tab P2

/* No outreg table created. See the log file for the output. */

*******************************************************
*** Appendix TABLE A6: Balance: Immigration reasons ***
*******************************************************

/* Showing the link between numberic value of variable and reasons.
   This is helpful for reading the outreg file. */
tabulate P2, generate(imm_reason)
tabulate P2, nolabel

*** Full sample ***
reg imm_reason1 
outreg2 using "tables/A6_Immigration_reason_All.xls", replace dec(3)
preserve
foreach x of numlist 1/7{

reg imm_reason`x' 
outreg2 using "tables/A6_Immigration_reason_All.xls", append dec(3)
reg imm_reason`x'  kuba_ethnicity
outreg2 using "tables/A6_Immigration_reason_All.xls", append dec(3)
reg imm_reason`x'  kuba_ethnicity `baseline_controls'
outreg2 using "tables/A6_Immigration_reason_All.xls", append dec(3)
}
restore

*** Central Kuba sample ***
preserve
keep if kuba_central==1 | lele_ethnicity==1
reg imm_reason1 
outreg2 using "tables/A6_Immigration_reason_Central_Kuba_Lele.xls", replace dec(3)

foreach x of numlist 1/7{
reg imm_reason`x' 
outreg2 using "tables/A6_Immigration_reason_Central_Kuba_Lele.xls", append dec(3)
reg imm_reason`x'  kuba_ethnicity
outreg2 using "tables/A6_Immigration_reason_Central_Kuba_Lele.xls", append dec(3)
reg imm_reason`x'  kuba_ethnicity `baseline_controls'
outreg2 using "tables/A6_Immigration_reason_Central_Kuba_Lele.xls", append dec(3)	
}
restore

*** Bushong sample ***

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
reg imm_reason1 
outreg2 using "tables/A6_Immigration_reason_Bushong_Lele.xls", replace dec(3)

foreach x of numlist 1/7{

reg imm_reason`x' 
outreg2 using "tables/A6_Immigration_reason_Bushong_Lele.xls", append dec(3)
reg imm_reason`x'  kuba_ethnicity
outreg2 using "tables/A6_Immigration_reason_Bushong_Lele.xls", append dec(3)
reg imm_reason`x'  kuba_ethnicity `baseline_controls'
outreg2 using "tables/A6_Immigration_reason_Bushong_Lele.xls", append dec(3)	
}
restore


**************************************************************************
*** Appendix table A7: Controling for first PC of immigration measures ***
**************************************************************************
pca immigrant_Kananga frac_life_Kananga group_same_ethnicity hhi_final percent_same
predict pc1 pc2

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' pc1
outreg2 using "tables/A7_Immigration_control_pc.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' pc1
outreg2 using "tables/A7_Immigration_control_pc.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' pc1
outreg2 using "tables/A7_Immigration_control_pc.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' pc1
outreg2 using "tables/A7_Immigration_control_pc.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' pc1
outreg2 using "tables/A7_Immigration_control_pc.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' pc1
outreg2 using "tables/A7_Immigration_control_pc.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
drop pc1 pc2


**************************************************************
*** Appendix table A8: Controling for immigration measures ***
**************************************************************
local immigration_controls "immigrant_Kananga frac_life_Kananga group_same_ethnicity hhi_final percent_same" 

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' `immigration_controls'
outreg2 using "tables/A8_Immigration_controls.xls", replace 
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' `immigration_controls'
outreg2 using "tables/A8_Immigration_controls.xls", append 
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' `immigration_controls'
outreg2 using "tables/A8_Immigration_controls.xls", append 
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' `immigration_controls'
outreg2 using "tables/A8_Immigration_controls.xls", append 
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' `immigration_controls'
outreg2 using "tables/A8_Immigration_controls.xls", append 
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' `immigration_controls'
outreg2 using "tables/A8_Immigration_controls.xls", append 
sum net_missing_dgug if e(sample)==1
restore

**************************************************************************
*** Appendix table A9: Restricting the sample to those born in Kananga ***
**************************************************************************

gen in_sample2=0
replace in_sample2=1 if immigrant_Kananga==0

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' if in_sample2==1
outreg2 using "tables/A9_Baseline_2nd_gen_only.xls", replace 
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' if in_sample2==1
outreg2 using "tables/A9_Baseline_2nd_gen_only.xls", append 
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' if in_sample2==1
outreg2 using "tables/A9_Baseline_2nd_gen_only.xls", append 
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' if in_sample2==1
outreg2 using "tables/A9_Baseline_2nd_gen_only.xls", append 
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' if in_sample2==1
outreg2 using "tables/A9_Baseline_2nd_gen_only.xls", append 
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' if in_sample2==1
outreg2 using "tables/A9_Baseline_2nd_gen_only.xls", append 
sum net_missing_dgug if e(sample)==1
restore
drop in_sample2

***********************************************************
*** Appendix TABLE A10: Controlling for crop suitability ***
***********************************************************
local geography_controls "suitability_maize suitability_cassava"  

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' `geography_controls', cluster(village_group)
outreg2 using "tables/A10_Geography_controls.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' `geography_controls', cluster(village_group)
outreg2 using "tables/A10_Geography_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' `geography_controls', cluster(village_group)
outreg2 using "tables/A10_Geography_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' `geography_controls', cluster(village_group)
outreg2 using "tables/A10_Geography_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
//* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' `geography_controls', cluster(village_group)
outreg2 using "tables/A10_Geography_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' `geography_controls', cluster(village_group)
outreg2 using "tables/A10_Geography_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore


***************************************************************************
*** Appendix table A11: Robustness to removing SE boundary observations ***
***************************************************************************

*** Panel A. Baseline ***
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A11_panelA_Robustness_SE_boundary_removal.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls'
outreg2 using "tables/A11_panelA_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls'
outreg2 using "tables/A11_panelA_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls'
outreg2 using "tables/A11_panelA_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls'
outreg2 using "tables/A11_panelA_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls'
outreg2 using "tables/A11_panelA_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*** Panel B. (10km) ***
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>10000
outreg2 using "tables/A11_panelB_Robustness_SE_boundary_removal.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>10000
outreg2 using "tables/A11_panelB_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>10000
outreg2 using "tables/A11_panelB_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>10000
outreg2 using "tables/A11_panelB_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>10000
outreg2 using "tables/A11_panelB_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>10000
outreg2 using "tables/A11_panelB_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*** Panel C. (20km) ***
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>20000
outreg2 using "tables/A11_panelC_Robustness_SE_boundary_removal.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>20000
outreg2 using "tables/A11_panelC_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>20000
outreg2 using "tables/A11_panelC_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>20000
outreg2 using "tables/A11_panelC_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>20000
outreg2 using "tables/A11_panelC_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>20000
outreg2 using "tables/A11_panelC_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*** Panel D. (30km) ***
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>30000
outreg2 using "tables/A11_panelD_Robustness_SE_boundary_removal.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>30000
outreg2 using "tables/A11_panelD_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>30000
outreg2 using "tables/A11_panelD_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>30000
outreg2 using "tables/A11_panelD_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>30000
outreg2 using "tables/A11_panelD_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>30000
outreg2 using "tables/A11_panelD_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*** Panel E. (40km) ***
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>40000
outreg2 using "tables/A11_panelE_Robustness_SE_boundary_removal.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>40000
outreg2 using "tables/A11_panelE_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>40000
outreg2 using "tables/A11_panelE_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>40000
outreg2 using "tables/A11_panelE_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>40000
outreg2 using "tables/A11_panelE_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>40000
outreg2 using "tables/A11_panelE_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*** Panel F. (50km) ***
*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>50000
outreg2 using "tables/A11_panelF_Robustness_SE_boundary_removal.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>50000
outreg2 using "tables/A11_panelF_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>50000
outreg2 using "tables/A11_panelF_Robustness_SE_boundary_removal.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' if dist_Kuba_non_river_boundary>50000
outreg2 using "tables/A11_panelF_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' if dist_Kuba_non_river_boundary>50000
outreg2 using "tables/A11_panelF_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' if dist_Kuba_non_river_boundary>50000
outreg2 using "tables/A11_panelF_Robustness_SE_boundary_removal.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

***********************************************************************
*** Appendix Table A12: Controlling for Trust in foreign researchers ***
***********************************************************************

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity trust_int_org trust_other_nat trust_univ `baseline_controls'
outreg2 using "tables/A12_Trust_Us_controls.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central trust_int_org trust_other_nat trust_univ `baseline_controls'
outreg2 using "tables/A12_Trust_Us_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong trust_int_org trust_other_nat trust_univ `baseline_controls'
outreg2 using "tables/A12_Trust_Us_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity trust_int_org trust_other_nat trust_univ `baseline_controls'
outreg2 using "tables/A12_Trust_Us_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central trust_int_org trust_other_nat trust_univ `baseline_controls'
outreg2 using "tables/A12_Trust_Us_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong trust_int_org trust_other_nat trust_univ `baseline_controls'
outreg2 using "tables/A12_Trust_Us_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*****************************************************
*** Appendix TABLE A13: Controlling for DG Offers ***
*****************************************************

* Citizen of Kananga
xi: reg k_pl1_gives c_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", replace dec(2)
sum k_pl1_gives if e(sample)==1
* Own tribe
xi: reg g_pl1_gives a_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum g_pl1_gives if e(sample)==1
* Other tribe
xi: reg h_pl1_gives b_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum h_pl1_gives if e(sample)==1
* Govt
xi: reg i_pl1_gives t_pl1_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum i_pl1_gives if e(sample)==1
* Average
xi: reg avg_gives DG_avg_gives kuba_ethnicity `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum avg_gives if e(sample)==1

preserve
keep if kuba_central==1 | lele_ethnicity==1
* Citizen of Kananga
xi: reg k_pl1_gives c_pl1_gives kuba_central `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum k_pl1_gives if e(sample)==1
* Own tribe
xi: reg g_pl1_gives a_pl1_gives kuba_central `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum g_pl1_gives if e(sample)==1
* Other tribe
xi: reg h_pl1_gives b_pl1_gives kuba_central `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum h_pl1_gives if e(sample)==1
* Govt
xi: reg i_pl1_gives t_pl1_gives kuba_central `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum i_pl1_gives if e(sample)==1
* Average
xi: reg avg_gives DG_avg_gives kuba_central `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
* Citizen of Kananga
xi: reg k_pl1_gives c_pl1_gives kuba_bushong `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum k_pl1_gives if e(sample)==1
* Own tribe
xi: reg g_pl1_gives a_pl1_gives kuba_bushong `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum g_pl1_gives if e(sample)==1
* Other tribe
xi: reg h_pl1_gives b_pl1_gives kuba_bushong `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum h_pl1_gives if e(sample)==1
* Govt
xi: reg i_pl1_gives t_pl1_gives kuba_bushong `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum i_pl1_gives if e(sample)==1
* Average
xi: reg avg_gives DG_avg_gives kuba_bushong `baseline_controls'
outreg2 using "tables/A13_DG_offer_control.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

************************************************************
*** Appendix table A14: Differences in game understanding ***
************************************************************

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' rag_tq_avg avg_wrong
outreg2 using "tables/A14_Test_question_control.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' rag_tq_avg avg_wrong
outreg2 using "tables/A14_Test_question_control.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' rag_tq_avg avg_wrong
outreg2 using "tables/A14_Test_question_control.xls", append dec(2) 
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' def_tq_avg avg_wrong
outreg2 using "tables/A14_Test_question_control.xls", append dec(2) 
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' def_tq_avg avg_wrong
outreg2 using "tables/A14_Test_question_control.xls", append dec(2) 
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' def_tq_avg avg_wrong
outreg2 using "tables/A14_Test_question_control.xls", append dec(2) 
sum net_missing_dgug if e(sample)==1
restore

******************************************************************************
*** Appendix table A15: Testing vertical transmission using obedience only ***
******************************************************************************

xi: reg obedience kuba_ethnicity `baseline_controls'
outreg2 using "tables/A15_Vertical_transmission_obedience_only.xls", replace dec(3)
sum obedience if e(sample)==1

preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg obedience kuba_ethnicity `baseline_controls'
outreg2 using "tables/A15_Vertical_transmission_obedience_only.xls", append dec(3)
sum obedience if e(sample)==1
restore

preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg obedience kuba_ethnicity `baseline_controls'
outreg2 using "tables/A15_Vertical_transmission_obedience_only.xls", append dec(3)
sum obedience if e(sample)==1
restore


**************************************************************************
*** Appendix table A16: Controlling for income (without height weight) ***
**************************************************************************

pca C35_1 ln_annual_income ln_hh_monthly_income unemployed education good_floor good_roof meals_per_day bed_hungry_pastweek /*height weight_height*/
predict pc2

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' pc2
outreg2 using "tables/A16_Income_controls_wo_height.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central  `baseline_controls' pc2
outreg2 using "tables/A16_Income_controls_wo_height.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' pc2
outreg2 using "tables/A16_Income_controls_wo_height.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' pc2
outreg2 using "tables/A16_Income_controls_wo_height.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' pc2
outreg2 using "tables/A16_Income_controls_wo_height.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' pc2
outreg2 using "tables/A16_Income_controls_wo_height.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
drop pc2


*************************************************************
*** Appendix table A17: Controlling for income (all vars) ***
*************************************************************

pca C35_1 ln_annual_income ln_hh_monthly_income unemployed education height weight_height good_floor good_roof meals_per_day bed_hungry_pastweek
predict pc1

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' pc1
outreg2 using "tables/A17_Income_controls_w_height.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central  `baseline_controls' pc1
outreg2 using "tables/A17_Income_controls_w_height.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' pc1
outreg2 using "tables/A17_Income_controls_w_height.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' pc1
outreg2 using "tables/A17_Income_controls_w_height.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' pc1
outreg2 using "tables/A17_Income_controls_w_height.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' pc1
outreg2 using "tables/A17_Income_controls_w_height.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
drop pc1 


************************************************************
*** Appendix table A18: Controlling for colonial contact ***
************************************************************
local I_mission "I_any_mission"
local I_colonial "I_dist_electricity_1951 I_dist_railroad_1951 I_dist_mines_1951"

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' `I_mission' `I_colonial', cluster(village_group)
outreg2 using "tables/A18_Colonial_controls.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' `I_mission' `I_colonial', cluster(village_group)
outreg2 using "tables/A18_Colonial_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' `I_mission' `I_colonial', cluster(village_group)
outreg2 using "tables/A18_Colonial_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' `I_mission' `I_colonial', cluster(village_group)
outreg2 using "tables/A18_Colonial_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' `I_mission' `I_colonial', cluster(village_group)
outreg2 using "tables/A18_Colonial_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' `I_mission' `I_colonial', cluster(village_group)
outreg2 using "tables/A18_Colonial_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*******************************************
*** Appendix Table A19: Mobutu controls ***
*******************************************
local IAT_controls "iat_leaders_q1 iat_leaders_q2 IAT_Mobutu"

*** RAG ***
/* Full sample */
xi: reg avg_gives kuba_ethnicity `baseline_controls' `IAT_controls'
outreg2 using "tables/A19_Mobutu_controls.xls", replace dec(2)
sum avg_gives if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg avg_gives kuba_central `baseline_controls' `IAT_controls'
outreg2 using "tables/A19_Mobutu_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore
/* Bushong & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg avg_gives kuba_bushong `baseline_controls' `IAT_controls'
outreg2 using "tables/A19_Mobutu_controls.xls", append dec(2)
sum avg_gives if e(sample)==1
restore

*** Missing Money ***
/* Full sample */
xi: reg net_missing_dgug kuba_ethnicity `baseline_controls' `IAT_controls'
outreg2 using "tables/A19_Mobutu_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
/* Central Kuba & Lele */
preserve
keep if kuba_central==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_central `baseline_controls' `IAT_controls'
outreg2 using "tables/A19_Mobutu_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore
/* Bushong Kuba & Lele */
preserve
keep if kuba_bushong==1 | lele_ethnicity==1
xi: reg net_missing_dgug kuba_bushong `baseline_controls' `IAT_controls'
outreg2 using "tables/A19_Mobutu_controls.xls", append dec(2)
sum net_missing_dgug if e(sample)==1
restore

*********************************************
*** Appendix Table A20: Trust regressions ***
*********************************************


* See output for varialbe v33 of Table 3 in the replication files from Nunn and Wantchekon (2011) available at:
* http://scholar.harvard.edu/nunn/pages/data-0

log close


